OC.L10N.register(
    "notes",
    {
    "Notes" : "Anotacions",
    "New note" : "Nova anotació",
    "_%n word_::_%n words_" : ["%n paraula","%n paraules"],
    "An error occurred!" : "S'ha produït un error!",
    "File error" : "Error al fitxer",
    "Delete note" : "Esborra l\\'anotació",
    "Favorite" : "Preferit",
    "No notes found" : "No s\\'han trobat anotacions"
},
"nplurals=2; plural=(n != 1);");
